# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/interface.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import types_pb2 as flyteidl_dot_core_dot_types__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/interface.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z0github.com/lyft/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x1d\x66lyteidl/core/interface.proto\x12\rflyteidl.core\x1a\x19\x66lyteidl/core/types.proto\x1a\x1c\x66lyteidl/core/literals.proto\"I\n\x08Variable\x12(\n\x04type\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.LiteralType\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x96\x01\n\x0bVariableMap\x12<\n\tvariables\x18\x01 \x03(\x0b\x32).flyteidl.core.VariableMap.VariablesEntry\x1aI\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.flyteidl.core.Variable:\x02\x38\x01\"i\n\x0eTypedInterface\x12*\n\x06inputs\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.VariableMap\x12+\n\x07outputs\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.VariableMap\"|\n\tParameter\x12$\n\x03var\x18\x01 \x01(\x0b\x32\x17.flyteidl.core.Variable\x12)\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\x16.flyteidl.core.LiteralH\x00\x12\x12\n\x08required\x18\x03 \x01(\x08H\x00\x42\n\n\x08\x62\x65havior\"\x9c\x01\n\x0cParameterMap\x12?\n\nparameters\x18\x01 \x03(\x0b\x32+.flyteidl.core.ParameterMap.ParametersEntry\x1aK\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.flyteidl.core.Parameter:\x02\x38\x01\x42\x32Z0github.com/lyft/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_types__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,])




_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='flyteidl.core.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='flyteidl.core.Variable.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='flyteidl.core.Variable.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=178,
)


_VARIABLEMAP_VARIABLESENTRY = _descriptor.Descriptor(
  name='VariablesEntry',
  full_name='flyteidl.core.VariableMap.VariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.core.VariableMap.VariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.core.VariableMap.VariablesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=331,
)

_VARIABLEMAP = _descriptor.Descriptor(
  name='VariableMap',
  full_name='flyteidl.core.VariableMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='flyteidl.core.VariableMap.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VARIABLEMAP_VARIABLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=331,
)


_TYPEDINTERFACE = _descriptor.Descriptor(
  name='TypedInterface',
  full_name='flyteidl.core.TypedInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.core.TypedInterface.inputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.core.TypedInterface.outputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=438,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='flyteidl.core.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var', full_name='flyteidl.core.Parameter.var', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default', full_name='flyteidl.core.Parameter.default', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='flyteidl.core.Parameter.required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='behavior', full_name='flyteidl.core.Parameter.behavior',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=440,
  serialized_end=564,
)


_PARAMETERMAP_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='flyteidl.core.ParameterMap.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.core.ParameterMap.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.core.ParameterMap.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=723,
)

_PARAMETERMAP = _descriptor.Descriptor(
  name='ParameterMap',
  full_name='flyteidl.core.ParameterMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='flyteidl.core.ParameterMap.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARAMETERMAP_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=723,
)

_VARIABLE.fields_by_name['type'].message_type = flyteidl_dot_core_dot_types__pb2._LITERALTYPE
_VARIABLEMAP_VARIABLESENTRY.fields_by_name['value'].message_type = _VARIABLE
_VARIABLEMAP_VARIABLESENTRY.containing_type = _VARIABLEMAP
_VARIABLEMAP.fields_by_name['variables'].message_type = _VARIABLEMAP_VARIABLESENTRY
_TYPEDINTERFACE.fields_by_name['inputs'].message_type = _VARIABLEMAP
_TYPEDINTERFACE.fields_by_name['outputs'].message_type = _VARIABLEMAP
_PARAMETER.fields_by_name['var'].message_type = _VARIABLE
_PARAMETER.fields_by_name['default'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERAL
_PARAMETER.oneofs_by_name['behavior'].fields.append(
  _PARAMETER.fields_by_name['default'])
_PARAMETER.fields_by_name['default'].containing_oneof = _PARAMETER.oneofs_by_name['behavior']
_PARAMETER.oneofs_by_name['behavior'].fields.append(
  _PARAMETER.fields_by_name['required'])
_PARAMETER.fields_by_name['required'].containing_oneof = _PARAMETER.oneofs_by_name['behavior']
_PARAMETERMAP_PARAMETERSENTRY.fields_by_name['value'].message_type = _PARAMETER
_PARAMETERMAP_PARAMETERSENTRY.containing_type = _PARAMETERMAP
_PARAMETERMAP.fields_by_name['parameters'].message_type = _PARAMETERMAP_PARAMETERSENTRY
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['VariableMap'] = _VARIABLEMAP
DESCRIPTOR.message_types_by_name['TypedInterface'] = _TYPEDINTERFACE
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['ParameterMap'] = _PARAMETERMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), dict(
  DESCRIPTOR = _VARIABLE,
  __module__ = 'flyteidl.core.interface_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Variable)
  ))
_sym_db.RegisterMessage(Variable)

VariableMap = _reflection.GeneratedProtocolMessageType('VariableMap', (_message.Message,), dict(

  VariablesEntry = _reflection.GeneratedProtocolMessageType('VariablesEntry', (_message.Message,), dict(
    DESCRIPTOR = _VARIABLEMAP_VARIABLESENTRY,
    __module__ = 'flyteidl.core.interface_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.VariableMap.VariablesEntry)
    ))
  ,
  DESCRIPTOR = _VARIABLEMAP,
  __module__ = 'flyteidl.core.interface_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.VariableMap)
  ))
_sym_db.RegisterMessage(VariableMap)
_sym_db.RegisterMessage(VariableMap.VariablesEntry)

TypedInterface = _reflection.GeneratedProtocolMessageType('TypedInterface', (_message.Message,), dict(
  DESCRIPTOR = _TYPEDINTERFACE,
  __module__ = 'flyteidl.core.interface_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.TypedInterface)
  ))
_sym_db.RegisterMessage(TypedInterface)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETER,
  __module__ = 'flyteidl.core.interface_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Parameter)
  ))
_sym_db.RegisterMessage(Parameter)

ParameterMap = _reflection.GeneratedProtocolMessageType('ParameterMap', (_message.Message,), dict(

  ParametersEntry = _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARAMETERMAP_PARAMETERSENTRY,
    __module__ = 'flyteidl.core.interface_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.ParameterMap.ParametersEntry)
    ))
  ,
  DESCRIPTOR = _PARAMETERMAP,
  __module__ = 'flyteidl.core.interface_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.ParameterMap)
  ))
_sym_db.RegisterMessage(ParameterMap)
_sym_db.RegisterMessage(ParameterMap.ParametersEntry)


DESCRIPTOR._options = None
_VARIABLEMAP_VARIABLESENTRY._options = None
_PARAMETERMAP_PARAMETERSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/schedule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/schedule.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1d\x66lyteidl/admin/schedule.proto\x12\x0e\x66lyteidl.admin\"G\n\tFixedRate\x12\r\n\x05value\x18\x01 \x01(\r\x12+\n\x04unit\x18\x02 \x01(\x0e\x32\x1d.flyteidl.admin.FixedRateUnit\"0\n\x0c\x43ronSchedule\x12\x10\n\x08schedule\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\t\"\xc1\x01\n\x08Schedule\x12\x1d\n\x0f\x63ron_expression\x18\x01 \x01(\tB\x02\x18\x01H\x00\x12)\n\x04rate\x18\x02 \x01(\x0b\x32\x19.flyteidl.admin.FixedRateH\x00\x12\x35\n\rcron_schedule\x18\x04 \x01(\x0b\x32\x1c.flyteidl.admin.CronScheduleH\x00\x12\x1e\n\x16kickoff_time_input_arg\x18\x03 \x01(\tB\x14\n\x12ScheduleExpression*.\n\rFixedRateUnit\x12\n\n\x06MINUTE\x10\x00\x12\x08\n\x04HOUR\x10\x01\x12\x07\n\x03\x44\x41Y\x10\x02\x42\x33Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)

_FIXEDRATEUNIT = _descriptor.EnumDescriptor(
  name='FixedRateUnit',
  full_name='flyteidl.admin.FixedRateUnit',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MINUTE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOUR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=368,
  serialized_end=414,
)
_sym_db.RegisterEnumDescriptor(_FIXEDRATEUNIT)

FixedRateUnit = enum_type_wrapper.EnumTypeWrapper(_FIXEDRATEUNIT)
MINUTE = 0
HOUR = 1
DAY = 2



_FIXEDRATE = _descriptor.Descriptor(
  name='FixedRate',
  full_name='flyteidl.admin.FixedRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.FixedRate.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='flyteidl.admin.FixedRate.unit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=120,
)


_CRONSCHEDULE = _descriptor.Descriptor(
  name='CronSchedule',
  full_name='flyteidl.admin.CronSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='flyteidl.admin.CronSchedule.schedule', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='flyteidl.admin.CronSchedule.offset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=170,
)


_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='flyteidl.admin.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cron_expression', full_name='flyteidl.admin.Schedule.cron_expression', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate', full_name='flyteidl.admin.Schedule.rate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cron_schedule', full_name='flyteidl.admin.Schedule.cron_schedule', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kickoff_time_input_arg', full_name='flyteidl.admin.Schedule.kickoff_time_input_arg', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ScheduleExpression', full_name='flyteidl.admin.Schedule.ScheduleExpression',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=173,
  serialized_end=366,
)

_FIXEDRATE.fields_by_name['unit'].enum_type = _FIXEDRATEUNIT
_SCHEDULE.fields_by_name['rate'].message_type = _FIXEDRATE
_SCHEDULE.fields_by_name['cron_schedule'].message_type = _CRONSCHEDULE
_SCHEDULE.oneofs_by_name['ScheduleExpression'].fields.append(
  _SCHEDULE.fields_by_name['cron_expression'])
_SCHEDULE.fields_by_name['cron_expression'].containing_oneof = _SCHEDULE.oneofs_by_name['ScheduleExpression']
_SCHEDULE.oneofs_by_name['ScheduleExpression'].fields.append(
  _SCHEDULE.fields_by_name['rate'])
_SCHEDULE.fields_by_name['rate'].containing_oneof = _SCHEDULE.oneofs_by_name['ScheduleExpression']
_SCHEDULE.oneofs_by_name['ScheduleExpression'].fields.append(
  _SCHEDULE.fields_by_name['cron_schedule'])
_SCHEDULE.fields_by_name['cron_schedule'].containing_oneof = _SCHEDULE.oneofs_by_name['ScheduleExpression']
DESCRIPTOR.message_types_by_name['FixedRate'] = _FIXEDRATE
DESCRIPTOR.message_types_by_name['CronSchedule'] = _CRONSCHEDULE
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
DESCRIPTOR.enum_types_by_name['FixedRateUnit'] = _FIXEDRATEUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FixedRate = _reflection.GeneratedProtocolMessageType('FixedRate', (_message.Message,), dict(
  DESCRIPTOR = _FIXEDRATE,
  __module__ = 'flyteidl.admin.schedule_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.FixedRate)
  ))
_sym_db.RegisterMessage(FixedRate)

CronSchedule = _reflection.GeneratedProtocolMessageType('CronSchedule', (_message.Message,), dict(
  DESCRIPTOR = _CRONSCHEDULE,
  __module__ = 'flyteidl.admin.schedule_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.CronSchedule)
  ))
_sym_db.RegisterMessage(CronSchedule)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULE,
  __module__ = 'flyteidl.admin.schedule_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Schedule)
  ))
_sym_db.RegisterMessage(Schedule)


DESCRIPTOR._options = None
_SCHEDULE.fields_by_name['cron_expression']._options = None
# @@protoc_insertion_point(module_scope)
